summaryrefslogtreecommitdiffstats
path: root/chrome/browser/extensions/install_tracker.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/extensions/install_tracker.h')
-rw-r--r--chrome/browser/extensions/install_tracker.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/extensions/install_tracker.h b/chrome/browser/extensions/install_tracker.h
index d3e94a4..c8b2c47 100644
--- a/chrome/browser/extensions/install_tracker.h
+++ b/chrome/browser/extensions/install_tracker.h
@@ -22,7 +22,7 @@ namespace extensions {
class ExtensionPrefs;
-class InstallTracker : public ProfileKeyedService,
+class InstallTracker : public BrowserContextKeyedService,
public content::NotificationObserver {
public:
InstallTracker(Profile* profile,
@@ -42,7 +42,7 @@ class InstallTracker : public ProfileKeyedService,
int percent_downloaded);
void OnInstallFailure(const std::string& extension_id);
// Overriddes for ProfileKeyedService:
virtual void Shutdown() OVERRIDE;
// content::NotificationObserver
@@ -42,7 +42,7 @@ class InstallTracker : public ProfileKeyedService,
int percent_downloaded);
void OnInstallFailure(const std::string& extension_id);
- // Overriddes for ProfileKeyedService:
+ // Overriddes for BrowserContextKeyedService:
virtual void Shutdown() OVERRIDE;
// content::NotificationObserver